@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# coding: utf8
 from typing import TypeVar
 from datetime import datetime
 from gphotos import Utils
@@ -11,27 +9,35 @@ import logging
 log = logging.getLogger(__name__)
 
 # this allows self reference to this class in its factory methods
-G = TypeVar('G', bound='GoogleAlbumsRow')
+G = TypeVar("G", bound="GoogleAlbumsRow")
 
 
 @DbRow.db_row
+# pylint: disable=no-member
 class GoogleAlbumsRow(DbRow):
     """
     generates a class with attributes for each of the columns in the
     SyncFiles table
     """
+
     table = "Albums"
-    cols_def = {'RemoteId': str, 'AlbumName': str, 'Size': int,
-                'StartDate': datetime,
-                'EndDate': datetime, 'SyncDate': datetime,
-                'Downloaded': bool}
+    cols_def = {
+        "RemoteId": str,
+        "AlbumName": str,
+        "Size": int,
+        "StartDate": datetime,
+        "EndDate": datetime,
+        "SyncDate": datetime,
+        "Downloaded": bool,
+    }
 
     def to_media(self) -> DatabaseMedia:
         db_media = DatabaseMedia(
             _id=self.RemoteId,
             _filename=self.AlbumName,
             _size=self.Size,
-            _create_date=self.EndDate)
+            _create_date=self.EndDate,
+        )
         return db_media
 
     @classmethod
@@ -46,7 +52,7 @@ class GoogleAlbumsRow(DbRow):
             Size=size,
             StartDate=start,
             EndDate=end,
-            SyncDate=Utils.date_to_string(
-                datetime.now()),
-            Downloaded=0)
+            SyncDate=Utils.date_to_string(datetime.now()),
+            Downloaded=0,
+        )
         return new_row
